@@ -1,7 +1,26 @@
+/*
+  Copyright (C) 2008 Ben Asselstine
+  Written by Ben Asselstine
+
+  This file is part of fileschanged.
+
+  fileschanged is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+
+  fileschanged is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with fileschanged; if not, write to the Free Software
+  Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301  USA
+*/
 #include <argp.h>
 #include <stdlib.h>
 #include <string.h>
-#include "gettext.h"
 #include "config.h"
 #include "opts.h"
 
